@@ -2,7 +2,7 @@ package Data::Processor;
 
 use strict;
 use 5.010_001;
-our $VERSION = '0.1.6';
+our $VERSION = '0.1.7';
 
 use Carp;
 use Data::Processor::Error::Collection;
@@ -66,30 +66,39 @@ sub validate{
     my %p    = @_;
 
     $self->{validator}=Data::Processor::Validator->new(
-        schema      => $self->{schema} // $p{schema},
-        data        => $data,
+        $self->{schema} // $p{schema},
         verbose     => $p{verbose} // $self->{verbose} // undef,
         errors      => $self->{errors},
         depth       => $self->{depth},
         indent      => $self->{indent},
         parent_keys => $self->{parent_keys},
     );
-    return $self->{validator}->validate();
+    return $self->{validator}->validate($data);
 }
 
 =head2 transform_data
 
 UNIMPLEMENTED
 
-Transform the data according to rules specified as callbacks that the
-module calls for you.
+Transform one key in the data according to rules specified
+as callbacks that themodule calls for you.
+Transforms the data in-place.
 
- my ($data_transformed, @errors) = $processor->transform_data(data=>$data);
+ my $validator = Data::Processor::Validator->new($schema, data => $data)
+ my $error_string = $processor->transform($key, $validator);
+
+This is not tremendously useful at the moment, especially because validate()
+transforms during validation.
 
 =cut
+# XXX make this traverse a data tree and transform everything
+# XXX across.
 sub transform_data{
-    die 'unimplemented';
-    #XXX
+    my $self = shift;
+    my $key  = shift;
+    my $val  = shift;
+
+    return Data::Processor::Transformer->new()->transform($key, $val);
 }
 
 =head2 transform_schema
